@@ -1,5 +1,5 @@
 `Mine.seis` <-
-  function(at1, at2, DB, grepsta, grepcomp, kind=1, CHOP=TRUE, verbose = FALSE)
+  function(at1, at2, DB, grepsta, grepcomp, kind=1, Iendian=1, BIGLONG=FALSE, CHOP=TRUE, verbose = FALSE)
 {
   ##  find all the files that overlap the times times
 #########   at1 and at2 should be single times in julian days
@@ -11,6 +11,8 @@
   if(missing(kind)) { kind = 1 }
   if(missing(CHOP)) { CHOP=TRUE }
   if(missing(verbose)) { verbose=FALSE }
+  if(missing(Iendian)) { Iendian=1 }
+     if(missing(BIGLONG)) { BIGLONG=TRUE}
 
   
 
@@ -76,7 +78,7 @@
   print(fn2)
 
   
-  KG4 = JGET.seis(fn2, kind = kind, PLOT = FALSE)
+  KG4 = JGET.seis(fn2, kind = kind,  Iendian=Iendian, BIGLONG= BIGLONG, HEADONLY=FALSE ,PLOT = FALSE)
 
   
   
